SearchResult class

Constructors

SearchResult({required List<AlbumSearchResult> albums, required List<SongSearchResult> songs, required List<PlaylistSearchResult> playlists, required List topQuery, required List<ArtistSearchResult> artists})
const

Properties

albums List<AlbumSearchResult>
final
artists List<ArtistSearchResult>
final
hashCode int
The hash code for this object.
no setterinherited
playlists List<PlaylistSearchResult>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
songs List<SongSearchResult>
final
topQuery List
final
topQueryAlbums List<AlbumSearchResult>
no setter
topQueryArtists List<ArtistSearchResult>
no setter
topQueryPlaylist List<PlaylistSearchResult>
no setter
topQuerySongs List<SongSearchResult>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited