TopSearchResult class
Constructors
- TopSearchResult(List topQuery)
Properties
-
albums
→ List<
AlbumSearchResult> -
no setter
-
artists
→ List<
ArtistSearchResult> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
playlist
→ List<
PlaylistSearchResult> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
songs
→ List<
SongSearchResult> -
no setter
- topQuery → List
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited